==> knews-0.9.3.tar.gz: knews-0.9.3/Widgets/Dialogue.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef _Dialogue_h
#define _Dialogue_h

#ifndef XtCMessage
#define XtCMessage "Message"
#endif
#ifndef XtCBuffer
#define XtCBuffer "Buffer"
#endif
#ifndef XtCLabel
#define XtCLabel "Label"
#endif

#ifndef XtNcursor
#define XtNcursor "cursor"
#endif
#ifndef XtNmessage
#define XtNmessage "message"
#endif
#ifndef XtNbuffer
#define XtNbuffer "buffer"
#endif
#ifndef XtNleftLabel
#define XtNleftLabel "leftLabel"
#endif
#ifndef XtNmiddleLabel
#define XtNmiddleLabel "middleLabel"
#endif
#ifndef XtNrightLabel
#define XtNrightLabel "rightLabel"
#endif

typedef struct _DialogueClassRec*  DialogueWidgetClass;
typedef struct _DialogueRec*       DialogueWidget;

extern WidgetClass dialogueWidgetClass;

typedef enum {
    DialogueReplyLeft,
    DialogueReplyMiddle,
    DialogueReplyRight,
    DialogueReplyEnter,
    DialogueReplyTab,
    DialogueReplyClose
} DialogueReply;

typedef struct {
    DialogueReply	reply;
    String		buffer;
} DialogueReport;

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOBEGIN
#endif

extern Widget DialogueCreateAndPopup(String, /* name */
				     Widget, /* parent */
				     String, /* message */
				     String, /* left knapp label or NULL */
				     String, /* middle knapp label or NULL */
				     String, /* right knapp label or NULL */
				     XtCallbackProc,
				     XtPointer, /* client_data */
				     XtGrabKind);

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOEND
#endif

#endif /* _Dialogue_h */

==> knews-0.9.6-4.tar.gz: knews-0.9.6/Widgets/Dialogue.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef Dialogue_h
#define Dialogue_h

#ifndef XtCMessage
#define XtCMessage "Message"
#endif
#ifndef XtCBuffer
#define XtCBuffer "Buffer"
#endif
#ifndef XtCLabel
#define XtCLabel "Label"
#endif

#ifndef XtNcursor
#define XtNcursor "cursor"
#endif
#ifndef XtNmessage
#define XtNmessage "message"
#endif
#ifndef XtNbuffer
#define XtNbuffer "buffer"
#endif
#ifndef XtNleftLabel
#define XtNleftLabel "leftLabel"
#endif
#ifndef XtNmiddleLabel
#define XtNmiddleLabel "middleLabel"
#endif
#ifndef XtNrightLabel
#define XtNrightLabel "rightLabel"
#endif

typedef struct DialogueClassRec*  DialogueWidgetClass;
typedef struct DialogueRec*       DialogueWidget;

extern WidgetClass dialogueWidgetClass;

typedef enum {
    DialogueReplyLeft,
    DialogueReplyMiddle,
    DialogueReplyRight,
    DialogueReplyEnter,
    DialogueReplyTab,
    DialogueReplyClose
} DialogueReply;

typedef struct {
    DialogueReply	reply;
    String		buffer;
} DialogueReport;

#endif /* Dialogue_h */
